==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapIdentityProviderMapperEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapIdentityProviderMapperEntityDelegate implements org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity> delegateProvider;
    public MapIdentityProviderMapperEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.ID, id).setId(id);
    }
    @Override public String getName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.NAME).getName();
    }
    @Override public void setName(String name) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.NAME, name).setName(name);
    }
    @Override public String getIdentityProviderAlias() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.IDENTITY_PROVIDER_ALIAS).getIdentityProviderAlias();
    }
    @Override public void setIdentityProviderAlias(String identityProviderAlias) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.IDENTITY_PROVIDER_ALIAS, identityProviderAlias).setIdentityProviderAlias(identityProviderAlias);
    }
    @Override public String getIdentityProviderMapper() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.IDENTITY_PROVIDER_MAPPER).getIdentityProviderMapper();
    }
    @Override public void setIdentityProviderMapper(String identityProviderMapper) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.IDENTITY_PROVIDER_MAPPER, identityProviderMapper).setIdentityProviderMapper(identityProviderMapper);
    }
    @Override public java.util.Map<String,String> getConfig() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.CONFIG).getConfig();
    }
    @Override public void setConfig(java.util.Map<String,String> config) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.CONFIG, config).setConfig(config);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapIdentityProviderMapperEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapIdentityProviderMapperEntityDelegate implements org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity, org.keycloak.models.map.common.delegate.HasDelegateProvider<org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity> {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity> delegateProvider;
    public MapIdentityProviderMapperEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    public org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntity> getDelegateProvider() {
        return this.delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.ID, id).setId(id);
    }
    @Override public String getName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.NAME).getName();
    }
    @Override public void setName(String name) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.NAME, name).setName(name);
    }
    @Override public String getIdentityProviderAlias() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.IDENTITY_PROVIDER_ALIAS).getIdentityProviderAlias();
    }
    @Override public void setIdentityProviderAlias(String identityProviderAlias) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.IDENTITY_PROVIDER_ALIAS, identityProviderAlias).setIdentityProviderAlias(identityProviderAlias);
    }
    @Override public String getIdentityProviderMapper() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.IDENTITY_PROVIDER_MAPPER).getIdentityProviderMapper();
    }
    @Override public void setIdentityProviderMapper(String identityProviderMapper) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.IDENTITY_PROVIDER_MAPPER, identityProviderMapper).setIdentityProviderMapper(identityProviderMapper);
    }
    @Override public java.util.Map<String,String> getConfig() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.CONFIG).getConfig();
    }
    @Override public void setConfig(java.util.Map<String,String> config) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapIdentityProviderMapperEntityFields.CONFIG, config).setConfig(config);
    }
}
